/**
 * XPointerService interaction.
 */
const XPOINTER_SERVICE_CONTRACTID = "@mozilla.org/xpointer-service;1";
const ANNOT_NS = "http://www.w3.org/2000/10/annotation-ns#";

var gXPointerService = null;

if (Components.classes[XPOINTER_SERVICE_CONTRACTID]) {
    gXPointerService = Components.classes[XPOINTER_SERVICE_CONTRACTID].getService().QueryInterface(Components.interfaces.nsIXPointerService);
}

function xptrIsServiceLoaded() { return (gXPointerService != null); }

function xptrResolveAnnotation(annotation, doc) {
    var range = null; // resolved range for xpointer
    // context is full uri including xpointer
    var context = annotation.data.getProperty(ANNOT_NS, "context");
    
    if (context) {
	// strip uri down to xpointer
	var index = context.indexOf("#");
	context = context.substring(index + 1);
	if (index != -1) {
	    try {
		return gXPointerService.parseXPointerToRange(context, doc);
	    }
	    catch(e) {
		dump("couldn't resolve annotation " + annotation.annotationURI + ": " + e + "\n");
	    }
	}
	else {
	    dump("couldn't find # in context: " + context + "\n");
	}
    }
    else {
	dump("couldn't get context for annotation: " + annotation.annotationURI + "\n");
    }
    
    // couldn't resolve annotation
    return null;
}

function xptrCreateXPointer(seln, doc) {
    return gXPointerService.createXPointerFromSelection(seln, doc);
}

function xptrMarkElement(element) {
    gXPointerService.markElement(element);
}